summaryrefslogtreecommitdiffstats
path: root/lib/kross/python/scripts/gui.py
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/python/scripts/gui.py')
-rwxr-xr-xlib/kross/python/scripts/gui.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kross/python/scripts/gui.py b/lib/kross/python/scripts/gui.py
index 9b8e0f8c..eda671cc 100755
--- a/lib/kross/python/scripts/gui.py
+++ b/lib/kross/python/scripts/gui.py
@@ -289,10 +289,10 @@ class QtDialog:
filename = None
try:
- print "QtDialog.FileChooser.browseButtonClicked() kfile.KFileDialog"
- # try to use the kfile module included in pytde
- import kfile
- filename = kfile.KFileDialog.getOpenFileName(self.initialfile, filtermask, self, "Save to file")
+ print "QtDialog.FileChooser.browseButtonClicked() tdefile.KFileDialog"
+ # try to use the tdefile module included in pytde
+ import tdefile
+ filename = tdefile.KFileDialog.getOpenFileName(self.initialfile, filtermask, self, "Save to file")
except:
print "QtDialog.FileChooser.browseButtonClicked() qt.QFileDialog"
# fallback to Qt filedialog